CLIXX Documentation
===================

.. image:: https://img.shields.io/pypi/v/clixx
    :target: https://pypi.org/project/clixx/

.. image:: https://img.shields.io/pypi/pyversions/clixx
    :target: https://pypi.org/project/clixx/

.. image:: https://pepy.tech/badge/clixx/month
    :target: https://pepy.tech/project/clixx

.. image:: https://img.shields.io/pypi/l/clixx
    :target: https://pypi.org/project/clixx/

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black

.. image:: https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336
    :target: https://pycqa.github.io/isort/

CLIXX is a command-line interface parser & framework for Python.

.. toctree::
    :hidden:

    api/index
